MethodChannelInnovaIDVerify class

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
imageChannel MethodChannel
final
methodChannel MethodChannel
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
processIDVerification({required String referenceNum, required void onVerificationComplete(Map<String, dynamic> verificationData), void onActivityClosed()?}) Future<String?>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited